@@ -8,12 +8,19 @@
 #'   allowed.
 #'
 #' @return A call object.
+#'
+#' @noRd
 make_import_call <- function(params, exports_only)
 {
-  if (exports_only)
-    substitute(assign(new, getExportedValue(nm, ns = ns), pos = pos),
-               params)
-  else
-    substitute(assign(new, get(nm, envir = ns, inherits = inh), pos = pos),
-               params)
+  cl <-
+    if (exports_only)
+       substitute(safe_assign(new, getExportedValue(nm, ns = ns), pos = pos),
+                  params)
+    else
+       substitute(safe_assign(new, get(nm, envir = ns, inherits = inh), pos = pos),
+                  params)
+
+  cl[[1]] <- safe_assign
+
+  cl
 }
